==> mastercard_qkr-1.1.0-py2-none-any.whl: mastercardqkr/formsubmission.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


from __future__ import absolute_import
from mastercardapicore import BaseObject
from mastercardapicore import RequestMap
from mastercardapicore import OperationConfig
from mastercardapicore import OperationMetadata
from mastercardqkr import ResourceConfig

class FormSubmission(BaseObject):
    """
    
    """

    __config = {
        
        "88dfa326-0615-4060-ad3e-944cf0d176f4" : OperationConfig("/labs/proxy/qkr2/internal/api2/formSubmission", "create", ["X-Auth-Token"], []),
        
        "40e5cb30-ea2b-440e-aa66-fac3f84b5e3f" : OperationConfig("/labs/proxy/qkr2/internal/api2/formSubmission", "query", ["X-Auth-Token"], ["merchantId"]),
        
    }

    def getOperationConfig(self,operationUUID):
        if operationUUID not in self.__config:
            raise Exception("Invalid operationUUID: "+operationUUID)

        return self.__config[operationUUID]

    def getOperationMetadata(self):
        return OperationMetadata(ResourceConfig.getInstance().getVersion(), ResourceConfig.getInstance().getHost(), ResourceConfig.getInstance().getContext(), ResourceConfig.getInstance().getJsonNative(), ResourceConfig.getInstance().getContentTypeOverride())


    @classmethod
    def create(cls,mapObj):
        """
        Creates object of type FormSubmission

        @param Dict mapObj, containing the required parameters to create a new object
        @return FormSubmission of the response of created instance.
        @raise ApiException: raised an exception from the response status
        """
        return BaseObject.execute("88dfa326-0615-4060-ad3e-944cf0d176f4", FormSubmission(mapObj))











    @classmethod
    def query(cls,criteria):
        """
        Query objects of type FormSubmission by id and optional criteria
        @param type criteria
        @return FormSubmission object representing the response.
        @raise ApiException: raised an exception from the response status
        """

        return BaseObject.execute("40e5cb30-ea2b-440e-aa66-fac3f84b5e3f", FormSubmission(criteria))

==> mastercard_qkr-1.3.0-py2-none-any.whl: mastercardqkr/formsubmission.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

#
# Copyright (c) 2016-2020 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


from __future__ import absolute_import
from mastercardapicore import BaseObject
from mastercardapicore import RequestMap
from mastercardapicore import OperationConfig
from mastercardapicore import OperationMetadata
from mastercardqkr import ResourceConfig

class FormSubmission(BaseObject):
    """
    
    """

    __config = {
        
        "7158df49-bf33-4a92-98e4-a85fdee4bd12" : OperationConfig("/labs/proxy/qkr2/internal/api2/formSubmission", "create", ["X-Auth-Token"], []),
        
        "fcee50d8-0c6e-4880-be09-cffec4c6d6fd" : OperationConfig("/labs/proxy/qkr2/internal/api2/formSubmission", "query", ["X-Auth-Token"], ["merchantId"]),
        
    }

    def getOperationConfig(self,operationUUID):
        if operationUUID not in self.__config:
            raise Exception("Invalid operationUUID: "+operationUUID)

        return self.__config[operationUUID]

    def getOperationMetadata(self):
        return OperationMetadata(ResourceConfig.getInstance().getVersion(), ResourceConfig.getInstance().getHost(), ResourceConfig.getInstance().getContext(), ResourceConfig.getInstance().getJsonNative(), ResourceConfig.getInstance().getContentTypeOverride())


    @classmethod
    def create(cls,mapObj):
        """
        Creates object of type FormSubmission

        @param Dict mapObj, containing the required parameters to create a new object
        @return FormSubmission of the response of created instance.
        @raise ApiException: raised an exception from the response status
        """
        return BaseObject.execute("7158df49-bf33-4a92-98e4-a85fdee4bd12", FormSubmission(mapObj))











    @classmethod
    def query(cls,criteria):
        """
        Query objects of type FormSubmission by id and optional criteria
        @param type criteria
        @return FormSubmission object representing the response.
        @raise ApiException: raised an exception from the response status
        """

        return BaseObject.execute("fcee50d8-0c6e-4880-be09-cffec4c6d6fd", FormSubmission(criteria))
